==> zither-1.1.13.tar.gz: zither_prj/apollon/menu_cnew.php <==
<?php

require("./total.inc");

session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(5)){
   exit;
   }



echo "<!DOCTYPE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN' 'http://www.w3.org/TR/html4/loose.dtd'>";
echo "<html lang='ja'>";
echo "<head>";
        echo "<meta http-equiv='Content-Type' content='text/html; charset=euc-jp'>";
        echo "<title>Zither server Administration tool 'Apollon'</title>";
echo "</head>";




$CNAME = $_GET["CNAME"];
$BNAME = $_GET["BNAME"];

print("<body alink='#ff0000' bgcolor='$my_bgcolor' link='#0000ff' text='#000000' vlink='#000080'>\n");

print("<TABLE border='0' bgcolor='FFA500' cellspacing='3' cellpadding='0' width=100%>");
print("<tr><td align=left><font color='ffffff'><b>ƻ -> ֥å饤</b></font></td></tr>");
print("</table>");

print("<br>");




$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
if(!$conn){
   echo "not connection!<br>";
   exit;
   }


//  ƻ֥å̾ꥹȺ
$bname_count = 0;
$result = pg_query($conn, "select distinct(bname) from userblock;");
if(!$result){
   print("banem select , bud query\n");
   exit;
   }
$num = pg_num_rows($result);
if($num > 0){
   while($bname_count < $num){
      $bname_data[$bname_count] = rtrim(pg_fetch_Result($result, $bname_count, bname));
      $result1=pg_query($conn,"select distinct(cname) from userblock where bname='$bname_data[$bname_count]';");
      if(!$result1){
         print("bname , canem select , bud query\n");
         exit;
         }
      $num1 = pg_num_rows($result1);
      if($num1 > 0){
         $cname_data[$bname_count] = rtrim(pg_fetch_Result($result1, 0, cname));
         }
      $bname_count++;
      }
   }
else{
   print("NG ƻ֥å̵Ǥ \n");
   }
pg_free_result($result);
pg_free_result($result1);



$cname_count = 0;
$result=pg_query($conn,"select distinct(cname) from connection;");
if(!$result){
   print("canem select , bud query\n");
   exit;
   }
$num = pg_num_rows($result);
if($num > 0){
   while($cname_count < $num){
      $xcname_data[$cname_count] = rtrim(pg_fetch_Result($result, $cname_count, cname));
      $cname_count++;
      }
   }


pg_free_result($result);


pg_Close($conn);









print("<FORM METHOD=GET ACTION='negdelete.php' target='top'>");
print("<tr><td><font color=red size=3>");
print("ƻ륯饤ѥǡ١zitherФδե˺ޤ<br>");
print("꤬ʤȥ饤Ȥzitherƻ륵Ф³ޤ<br>");
print("ưꤹȡưδƻ֥åñ̤ǰư˰ܤΥ饤Ȥޤ<br>");
print("âư褬¸ߤʤϤΤޤ޺Ƥޤޤ<br>");
print("</td></tr>");
print("Υܥ򲡤ȺڡӤޤ<br>");
print("</font>");
print("饤̾");
// print("<INPUT type='text' NAME=CNAME size='12' value='$CNAME'>");
echo "<select size=1 name=CNAME>";
echo "<option value='$CNAME'>$CNAME";
for($select_count = 0; $select_count < $cname_count; $select_count++){
   echo "<option value=$xcname_data[$select_count]>$xcname_data[$select_count]";
   }
echo "</select>";
print("ư饤̾");
//print("<INPUT type='text' NAME=CNAME2 size='12' value=''>");
echo "<select size=1 name=CNAME2>";
echo "<option value=''>";
for($select_count = 0; $select_count < $cname_count; $select_count++){
   echo "<option value=$xcname_data[$select_count]>$xcname_data[$select_count]";
   }
echo "</select>";
print("<input type=submit value='饤Ⱥ'>");
print("</form>");

print("<br><br>");

print("<FORM METHOD=GET ACTION='block_delete.php' target='top'>");
print("<tr><td><font color=red size=3>");
print("</td></tr>");
print("֥åޤ<br>");
print("֥åδƻܤƾäޤΤǤա<br>");
print("Υܥ򲡤ȺڡӤޤ<br>");
print("</font>");
print("֥å̾");
// print("<INPUT type='text' NAME=BNAME size='12' value='$BNAME'>");
echo "<select size=1 name=BNAME>";
echo "<option value='$BNAME'>$BNAME";
for($select_count = 0; $select_count < $bname_count; $select_count++){
   echo "<option value=$bname_data[$select_count]>$bname_data[$select_count] ($cname_data[$select_count])";
   }
echo "</select>";

print("<input type=submit value='֥å'>");
print("</form>");

print("<br><br>");

print("<FORM METHOD=GET ACTION='block_delete.php' target='top'>");
print("<tr><td><font color=red size=3>");
print("</td></tr>");
print("֥å򤽤Τޤ¾δƻ륯饤Ȥ˰ưޤ<br>");
print("ưǤΤǡưΥ֥åϾäޤΤǤա<br>");
print("Υܥ򲡤ȰưڡӤޤ<br>");
print("</font>");
print("ư֥å̾");
// print("<INPUT type='text' NAME=BNAME size='12' value='$BNAME'>");
echo "<select size=1 name=BNAME>";
echo "<option value='$BNAME'>$BNAME";
for($select_count = 0; $select_count < $bname_count; $select_count++){
   echo "<option value=$bname_data[$select_count]>$bname_data[$select_count] ($cname_data[$select_count])";
   }
echo "</select>";
print("ưƻ륯饤̾");
// print("<INPUT type='text' NAME=CNAME size='12' value='$CNAME'>");
echo "<select size=1 name=CNAME>";
echo "<option value='$CNAME'>$CNAME";
for($select_count = 0; $select_count < $cname_count; $select_count++){
   echo "<option value=$xcname_data[$select_count]>$xcname_data[$select_count]";
   }
echo "</select>";
print("<input type=submit value='֥åư'>");
print("</form>");

print("<br><br>");

print("<FORM METHOD=GET ACTION='block_delete.php' target='top'>");
print("<tr><td><font color=red size=3>");
print("</td></tr>");
print("֥å̾ѹޤ<br>");
print("֥å̾¸ߤϤʤˤԤޤ<br>");
print("Υܥ򲡤ȰưڡӤޤ<br>");
print("</font>");
print("ѹ֥å̾");
// print("<INPUT type='text' NAME=BNAME size='12' value='$BNAME'>");
echo "<select size=1 name=BNAME>";
echo "<option value='$BNAME'>$BNAME";
for($select_count = 0; $select_count < $bname_count; $select_count++){
   echo "<option value=$bname_data[$select_count]>$bname_data[$select_count] ($cname_data[$select_count])";
   }
echo "</select>";
print("ѹ֥å̾");
print("<INPUT type='text' NAME=BNAME2 size='12' value=''>");
// echo "<select size=1 name=BNAME2>";
// echo "<option value=''>";
// for($select_count = 0; $select_count < $bname_count; $select_count++){
//    echo "<option value=$bname_data[$select_count]>$bname_data[$select_count] ($cname_data[$select_count])";
//    }
echo "</select>";
print("<input type=submit value='֥åư'>");
print("</form>");

print("<br><br>");


print("<FORM METHOD=GET ACTION='block_newedit.php' target='top'>");
print("<tr><td><font color=red size=3>");
print("</td></tr>");
print("֥å<br>");
print("֥å̾¸ߤԽˤʤޤ<br>");
print("Υܥ򲡤ԽڡӤޤ<br>");
print("</font>");
print("ѹ֥å̾");
// print("<INPUT type='text' NAME=BNAME size='12' value='$BNAME'>");
echo "<select size=1 name=BNAME>";
echo "<option value='$BNAME'>$BNAME";
for($select_count = 0; $select_count < $bname_count; $select_count++){
   echo "<option value=$bname_data[$select_count]>$bname_data[$select_count] ($cname_data[$select_count])";
   }
echo "</select>";
print("<input type=submit value='֥å Խ'>");
print("</form>");

print("<br><br>");


?>


</body>
</html>

==> zither-1.1.15.tar.gz: zither_prj/apollon/menu_cnew.php <==
<?php

require("./total.inc");

session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(5)){
   exit;
   }



echo "<!DOCTYPE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN' 'http://www.w3.org/TR/html4/loose.dtd'>";
echo "<html lang='ja'>";
echo "<head>";
        echo "<meta http-equiv='Content-Type' content='text/html; charset=euc-jp'>";
        echo "<title>Zither server Administration tool 'Apollon'</title>";
echo "</head>";




$CNAME = enco($_GET["CNAME"]);
$BNAME = enco($_GET["BNAME"]);

print("<body alink='#ff0000' bgcolor='$my_bgcolor' link='#0000ff' text='#000000' vlink='#000080'>\n");

print("<TABLE border='0' bgcolor='FFA500' cellspacing='3' cellpadding='0' width=100%>");
print("<tr><td align=left><font color='ffffff'><b>ƻ -> ֥å饤</b></font></td></tr>");
print("</table>");

print("<br>");




$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
if(!$conn){
   echo "not connection!<br>";
   exit;
   }


//  ƻ֥å̾ꥹȺ
$bname_count = 0;
$result = pg_query($conn, "select distinct(bname) from userblock;");
if(!$result){
   print("banem select , bud query\n");
   exit;
   }
$num = pg_num_rows($result);
if($num > 0){
   while($bname_count < $num){
      $bname_data[$bname_count] = enco_rtrim(pg_fetch_Result($result, $bname_count, bname));
      $result1=pg_query($conn,"select distinct(cname) from userblock where bname='$bname_data[$bname_count]';");
      if(!$result1){
         print("bname , canem select , bud query\n");
         exit;
         }
      $num1 = pg_num_rows($result1);
      if($num1 > 0){
         $cname_data[$bname_count] = enco_rtrim(pg_fetch_Result($result1, 0, cname));
         }
      $bname_count++;
      }
   }
else{
   print("NG ƻ֥å̵Ǥ \n");
   }
pg_free_result($result);
pg_free_result($result1);



$cname_count = 0;
$result=pg_query($conn,"select distinct(cname) from connection;");
if(!$result){
   print("canem select , bud query\n");
   exit;
   }
$num = pg_num_rows($result);
if($num > 0){
   while($cname_count < $num){
      $xcname_data[$cname_count] = enco_rtrim(pg_fetch_Result($result, $cname_count, cname));
      $cname_count++;
      }
   }


pg_free_result($result);


pg_Close($conn);









print("<FORM METHOD=GET ACTION='negdelete.php' target='top'>");
print("<tr><td><font color=red size=3>");
print("ƻ륯饤ѥǡ١zitherФδե˺ޤ<br>");
print("꤬ʤȥ饤Ȥzitherƻ륵Ф³ޤ<br>");
print("ưꤹȡưδƻ֥åñ̤ǰư˰ܤΥ饤Ȥޤ<br>");
print("âư褬¸ߤʤϤΤޤ޺Ƥޤޤ<br>");
print("</td></tr>");
print("Υܥ򲡤ȺڡӤޤ<br>");
print("</font>");
print("饤̾");
// print("<INPUT type='text' NAME=CNAME size='12' value='$CNAME'>");
echo "<select size=1 name=CNAME>";
echo "<option value='$CNAME'>$CNAME";
for($select_count = 0; $select_count < $cname_count; $select_count++){
   echo "<option value=$xcname_data[$select_count]>$xcname_data[$select_count]";
   }
echo "</select>";
print("ư饤̾");
//print("<INPUT type='text' NAME=CNAME2 size='12' value=''>");
echo "<select size=1 name=CNAME2>";
echo "<option value=''>";
for($select_count = 0; $select_count < $cname_count; $select_count++){
   echo "<option value=$xcname_data[$select_count]>$xcname_data[$select_count]";
   }
echo "</select>";
print("<input type=submit value='饤Ⱥ'>");
print("</form>");

print("<br><br>");

print("<FORM METHOD=GET ACTION='block_delete.php' target='top'>");
print("<tr><td><font color=red size=3>");
print("</td></tr>");
print("֥åޤ<br>");
print("֥åδƻܤƾäޤΤǤա<br>");
print("Υܥ򲡤ȺڡӤޤ<br>");
print("</font>");
print("֥å̾");
// print("<INPUT type='text' NAME=BNAME size='12' value='$BNAME'>");
echo "<select size=1 name=BNAME>";
echo "<option value='$BNAME'>$BNAME";
for($select_count = 0; $select_count < $bname_count; $select_count++){
   echo "<option value=$bname_data[$select_count]>$bname_data[$select_count] ($cname_data[$select_count])";
   }
echo "</select>";

print("<input type=submit value='֥å'>");
print("</form>");

print("<br><br>");

print("<FORM METHOD=GET ACTION='block_delete.php' target='top'>");
print("<tr><td><font color=red size=3>");
print("</td></tr>");
print("֥å򤽤Τޤ¾δƻ륯饤Ȥ˰ưޤ<br>");
print("ưǤΤǡưΥ֥åϾäޤΤǤա<br>");
print("Υܥ򲡤ȰưڡӤޤ<br>");
print("</font>");
print("ư֥å̾");
// print("<INPUT type='text' NAME=BNAME size='12' value='$BNAME'>");
echo "<select size=1 name=BNAME>";
echo "<option value='$BNAME'>$BNAME";
for($select_count = 0; $select_count < $bname_count; $select_count++){
   echo "<option value=$bname_data[$select_count]>$bname_data[$select_count] ($cname_data[$select_count])";
   }
echo "</select>";
print("ưƻ륯饤̾");
// print("<INPUT type='text' NAME=CNAME size='12' value='$CNAME'>");
echo "<select size=1 name=CNAME>";
echo "<option value='$CNAME'>$CNAME";
for($select_count = 0; $select_count < $cname_count; $select_count++){
   echo "<option value=$xcname_data[$select_count]>$xcname_data[$select_count]";
   }
echo "</select>";
print("<input type=submit value='֥åư'>");
print("</form>");

print("<br><br>");

print("<FORM METHOD=GET ACTION='block_delete.php' target='top'>");
print("<tr><td><font color=red size=3>");
print("</td></tr>");
print("֥å̾ѹޤ<br>");
print("֥å̾¸ߤϤʤˤԤޤ<br>");
print("Υܥ򲡤ȰưڡӤޤ<br>");
print("</font>");
print("ѹ֥å̾");
// print("<INPUT type='text' NAME=BNAME size='12' value='$BNAME'>");
echo "<select size=1 name=BNAME>";
echo "<option value='$BNAME'>$BNAME";
for($select_count = 0; $select_count < $bname_count; $select_count++){
   echo "<option value=$bname_data[$select_count]>$bname_data[$select_count] ($cname_data[$select_count])";
   }
echo "</select>";
print("ѹ֥å̾");
print("<INPUT type='text' NAME=BNAME2 size='12' value=''>");
// echo "<select size=1 name=BNAME2>";
// echo "<option value=''>";
// for($select_count = 0; $select_count < $bname_count; $select_count++){
//    echo "<option value=$bname_data[$select_count]>$bname_data[$select_count] ($cname_data[$select_count])";
//    }
echo "</select>";
print("<input type=submit value='֥åư'>");
print("</form>");

print("<br><br>");


print("<FORM METHOD=GET ACTION='block_newedit.php' target='top'>");
print("<tr><td><font color=red size=3>");
print("</td></tr>");
print("֥å<br>");
print("֥å̾¸ߤԽˤʤޤ<br>");
print("Υܥ򲡤ԽڡӤޤ<br>");
print("</font>");
print("ѹ֥å̾");
// print("<INPUT type='text' NAME=BNAME size='12' value='$BNAME'>");
echo "<select size=1 name=BNAME>";
echo "<option value='$BNAME'>$BNAME";
for($select_count = 0; $select_count < $bname_count; $select_count++){
   echo "<option value=$bname_data[$select_count]>$bname_data[$select_count] ($cname_data[$select_count])";
   }
echo "</select>";
print("<input type=submit value='֥å Խ'>");
print("</form>");

print("<br><br>");


?>


</body>
</html>
